@@ -22,12 +22,14 @@ class prepr:
     def kwargs(self, d: typing.Any = MISSING, **kv) -> "prepr": ...
     def attr(self, k, v, d: typing.Any = MISSING) -> "prepr": ...
     def attrs(self, d: typing.Any = MISSING, **kv) -> "prepr": ...
-    def _format_args(self, exc: dict[int, str], i: str, lb: str) -> str: ...
-    def _format_attrs(self, exc: dict[int, str], lb: str) -> str: ...
+    def _format_args(self, exc: typing.Dict[int, str], i: str,
+                     lb: str) -> str: ...
+    def _format_attrs(self, exc: typing.Dict[int, str], lb: str) -> str: ...
     def _build_collapsed(self) -> pstr: ...
-    def _build_simple(self, exc: dict[int, str], i: str, lb: str) -> str: ...
+    def _build_simple(self, exc: typing.Dict[int, str], i: str,
+                      lb: str) -> str: ...
     def build(self, simple: bool = False, collapsed: bool = False,
-              return_prepr: bool = False) -> pstr: ...
+              return_prepr: bool = False) -> "typing.Union[pstr, prepr]": ...
 
 
 class Colorspace:
